@@ -10,6 +10,7 @@ pyAgrum includes :
   * a `website <http://agrum.org>`_.
 """
 
+
 # aGrum Licence (LGPL)
 # -------------------
 #*   This program is free software; you can redistribute it and/or modify  *
@@ -27,11 +28,13 @@ pyAgrum includes :
 #*   Free Software Foundation, Inc.,                                       *
 #*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-__version__ = '0.22.5'
+__version__ = '0.22.9'
 __license__ = __doc__
 __project_url__ = 'http://agrum.org'
 
+import warnings
 import numpy as np
+
 from .deprecated import *
 
 # selection of imports extracted from dir(.pyAgrum)
@@ -56,11 +59,9 @@ from .pyAgrum import PRMexplorer
 from .pyAgrum import ApproximationScheme
 
 from .pyAgrum import initRandom, randomProba, randomDistribution, randomGeneratorSeed, getRandomGenerator, randomValue
-from .pyAgrum import isOMP, setNumberOfThreads, getThreadNumber, getNumberOfRunningThreads, getNumberOfLogicalProcessors, getMaxNumberOfThreads, getDynamicThreadsNumber, setDynamicThreadsNumber
+from .pyAgrum import isOMP, getNumberOfThreads, getMaxNumberOfThreads, getNumberOfLogicalProcessors, setNumberOfThreads
 
-from .pyAgrum import getNestedParallelism, setNestedParallelism
-
-from .pyAgrum import VarType_Discretized,VarType_Labelized,VarType_Range
+from .pyAgrum import VarType_Discretized,VarType_Labelized,VarType_Range,VarType_Integer
 
 from .pyAgrum import DefaultInLabel, DuplicateElement, DuplicateLabel, GumException, FatalError, FormatNotFound, GraphError, IOError, InvalidArc, InvalidArgument, InvalidArgumentsNumber, InvalidDirectedCycle, InvalidEdge, InvalidNode, DatabaseError, MissingValueInDatabase, MissingVariableInDatabase, NoChild, NoNeighbour, NoParent, NotFound, NullElement, OperationNotAllowed, OutOfBounds, ArgumentError, SizeError, SyntaxError, UndefinedElement, UndefinedIteratorKey, UndefinedIteratorValue, UnknownLabelInDatabase, CPTError
 
@@ -93,16 +94,12 @@ __all__=[
   'PRMexplorer',
 
   'ApproximationScheme',
-
-  'initRandom','randomProba','randomDistribution',
-  'isOMP','setNumberOfThreads','getNumberOfLogicalProcessors','getMaxNumberOfThreads',
-
   'initRandom','randomProba','randomDistribution','randomGeneratorSeed','getRandomGenerator','randomValue',
-  'isOMP','setNumberOfThreads','getThreadNumber','getNumberOfRunningThreads','getNumberOfLogicalProcessors','getMaxNumberOfThreads','getDynamicThreadsNumber','setDynamicThreadsNumber',
 
-  'getNestedParallelism', 'setNestedParallelism',
+  'isOMP','setNumberOfThreads','getNumberOfThreads','getMaxNumberOfThreads','getNumberOfLogicalProcessors',
+  #'getThreadNumber','getNumberOfRunningThreads','getDynamicThreadsNumber','setDynamicThreadsNumber','getNestedParallelism', 'setNestedParallelism',
 
-  'VarType_Discretized', 'VarType_Labelized', 'VarType_Range',
+  'VarType_Discretized', 'VarType_Labelized', 'VarType_Range','VarType_Integer',
 
   'DefaultInLabel', 'DuplicateElement', 'DuplicateLabel', 'GumException', 'FatalError', 'FormatNotFound', 'GraphError', 'IOError', 'InvalidArc', 'InvalidArgument', 'InvalidArgumentsNumber', 'InvalidDirectedCycle', 'InvalidEdge', 'InvalidNode', 'DatabaseError', 'MissingValueInDatabase', 'MissingVariableInDatabase', 'NoChild', 'NoNeighbour', 'NoParent', 'NotFound', 'NullElement', 'OperationNotAllowed', 'OutOfBounds', 'ArgumentError', 'SizeError', 'SyntaxError', 'UndefinedElement', 'UndefinedIteratorKey', 'UndefinedIteratorValue', 'UnknownLabelInDatabase',"CPTError",
 
@@ -115,6 +112,14 @@ initRandom(0)
 # configuration object
 from .config import PyAgrumConfiguration
 config = PyAgrumConfiguration()
+
+def _update_config_core():
+  # hook to control some parameters for core params
+  setNumberOfThreads(int(config['core','default_maxNumberOfThreads']))
+
+config.add_hook(_update_config_core)
+config.run_hooks()
+
 try:
   # load custom configuration if any
   config.load()
@@ -126,7 +131,7 @@ def about():
   about() for pyAgrum
 
   """
-  print("pyAgrum 0.22.5")
+  print("pyAgrum 0.22.9")
   print("(c) 2015-2021 Pierre-Henri Wuillemin, Christophe Gonzales")
   print("""
     This is free software; see the source code for copying conditions.
@@ -358,7 +363,7 @@ def fastBN(structure, domain_size=2):
 Create a Bayesian network with a dot-like syntax which specifies:
     - the structure 'a->b->c;b->d<-e;',
     - the type of the variables with different syntax (cf documentation).
-    
+
 Examples
 --------
 >>> import pyAgrum as gum
@@ -374,7 +379,7 @@ domain_size : int
 Returns
 -------
 pyAgrum.BayesNet
-        the resulting bayesian network 
+        the resulting bayesian network
   """
   return BayesNet.fastPrototype(structure, domain_size)
 
@@ -399,7 +404,7 @@ domain_size : int
 Returns
 -------
 pyAgrum.MarkovNet
-        the resulting Markov network 
+        the resulting Markov network
   """
   return MarkovNet.fastPrototype(structure, domain_size)
 
@@ -415,7 +420,7 @@ Create an Influence Diagram with a modified dot-like syntax which specifies:
       - ``a`` : a chance node named 'a' (by default)
       - ``$a`` : a utility node named 'a'
       - ``*a`` : a decision node named 'a'
-    
+
 Examples
 --------
 >>> import pyAgrum as gum
@@ -448,7 +453,7 @@ def getPosterior(model, evs, target):
   Parameters
   ----------
   bn : pyAgrum.BayesNet or pyAgrum.MarkovNet
-    The probabilistic Graphical Model   
+    The probabilistic Graphical Model
   evs:  dictionaryDict
     {name/id:val, name/id : [ val1, val2 ], ...}
   target: string or int
@@ -472,23 +477,23 @@ def getPosterior(model, evs, target):
   return Potential(inf.posterior(target))
 
 
-def generateCSV(bn, name_out, n, show_progress=False, with_labels=False, random_order=True):
+def generateSample(bn, n=1, name_out=None, show_progress=False, with_labels=False, random_order=True):
   """
   generate a CSV file of samples from a bn.
 
   :param bn: the BN from which the sample is generated
   :type bn: pyAgrum.BayesNet
-  :param name_out: the name for the output filename
-  :type name_out: string
   :param n: the number of samples
   :type n: int
+  :param name_out: the name for the output csv filename. If name_out is None, a pandas.DataFrame is generated
+  :type name_out: string
   :param show_progress: if True, show a progress bar
   :type show_progress: boolean
   :param with_labels: if True, use the labels of the modalities of variables in the csv. If False, use their ids.
   :type with_labels: boolean
   :param random_order: if True, the columns in the csv are randomized sorted
-  :type random_order: boolean  
-  :return: the log2-likelihood of the generated base
+  :type random_order: boolean
+  :return: the log2-likelihood of the generated base or if name_out is None, the couple (generated pandas.DataFrame,log2-likelihood)
   """
 
   genere = BNDatabaseGenerator(bn)
@@ -510,19 +515,38 @@ def generateCSV(bn, name_out, n, show_progress=False, with_labels=False, random_
     genere.setRandomVarOrder()
   ll = genere.drawSamples(n)
 
-  genere.toCSV(name_out, with_labels)
+  if name_out is not None:
+    genere.toCSV(name_out, with_labels)
 
   if show_progress:
     print(f"Log2-Likelihood : {ll}")
 
-  return ll
+  if name_out is not None:
+    return ll
+  else:
+    return genere.to_pandas(with_labels),ll
+
+
+def generateCSV(bn, name_out, n=1, show_progress=False, with_labels=False, random_order=True):
+  """
+  Deprecated. Please use `pyAgrum.generateSample` instead.
+  """
+  warnings.warn(f"""
+  ** pyAgrum.generatedCSV is deprecated since pyAgrum>0.22.7.
+  ** A call to 
+      'generateSample(bn, {n=}, {name_out=}, {show_progress=}, {with_labels=}, {random_order=})' 
+  ** is executed.
+    
+  """, DeprecationWarning, stacklevel=2)
+
+  generateSample(bn,n,name_out,show_progress,with_labels,random_order)
 
 def log2(p):
   """Compute p.log2() in a new Potential without modifying p
-  
+
   Parameters
   ----------
-  p : pyAgrum.Potential 
+  p : pyAgrum.Potential
     The potential on which to apply log2 function
 
   Returns
